package
Version:
v0.0.0-...-3e11984
Opens a new window with list of versions in this module.
Published: Dec 4, 2025
License: BSD-4-Clause
Opens a new window with license information.
Imports: 11
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type HttpMgr struct {
ListenAddr string
}
使用gin库做为路由的http服务
Source Files
¶
Click to show internal directories.
Click to hide internal directories.